==> libreoffice-still-debug-25.2.7-4-x86_64.pkg.tar.zst: usr/src/debug/libreoffice-still/libreoffice-25.2.7.2/workdir/UnoApiHeadersTarget/offapi/normal/com/sun/star/ucb/DuplicateProviderException.hpp <==
#ifndef INCLUDED_COM_SUN_STAR_UCB_DUPLICATEPROVIDEREXCEPTION_HPP
#define INCLUDED_COM_SUN_STAR_UCB_DUPLICATEPROVIDEREXCEPTION_HPP

#include "sal/config.h"

#include "com/sun/star/ucb/DuplicateProviderException.hdl"

#include "com/sun/star/uno/Exception.hpp"
#include "com/sun/star/uno/Type.hxx"
#include "cppu/unotype.hxx"

namespace com { namespace sun { namespace star { namespace ucb {

inline DuplicateProviderException::DuplicateProviderException(
#if defined LIBO_USE_SOURCE_LOCATION
    LIBO_USE_SOURCE_LOCATION::source_location location
#endif
    )
    : ::css::uno::Exception(
#if defined LIBO_USE_SOURCE_LOCATION
    location
#endif
)
{ }

inline DuplicateProviderException::DuplicateProviderException(const ::rtl::OUString& Message_, const ::css::uno::Reference< ::css::uno::XInterface >& Context_
#if defined LIBO_USE_SOURCE_LOCATION
    , LIBO_USE_SOURCE_LOCATION::source_location location
#endif
)
    : ::css::uno::Exception(Message_, Context_
#if defined LIBO_USE_SOURCE_LOCATION
    , location
#endif
)
{ }

#if !defined LIBO_INTERNAL_ONLY
DuplicateProviderException::DuplicateProviderException(DuplicateProviderException const & the_other): ::css::uno::Exception(the_other) {}

DuplicateProviderException::~DuplicateProviderException() {}

DuplicateProviderException & DuplicateProviderException::operator =(DuplicateProviderException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::css::uno::Exception::operator =(the_other);
    return *this;
}
#endif

} } } }

namespace com { namespace sun { namespace star { namespace ucb {

inline ::css::uno::Type const & cppu_detail_getUnoType(SAL_UNUSED_PARAMETER ::css::ucb::DuplicateProviderException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.ucb.DuplicateProviderException" );
    }
    return * reinterpret_cast< ::css::uno::Type * >( &the_type );
}

} } } }

SAL_DEPRECATED("use cppu::UnoType") inline ::css::uno::Type const & SAL_CALL getCppuType(SAL_UNUSED_PARAMETER ::css::ucb::DuplicateProviderException const *) {
    return ::cppu::UnoType< ::css::ucb::DuplicateProviderException >::get();
}

#endif // INCLUDED_COM_SUN_STAR_UCB_DUPLICATEPROVIDEREXCEPTION_HPP

==> libreoffice-still-debug-25.8.5-1-x86_64.pkg.tar.zst: usr/src/debug/libreoffice-still/libreoffice-25.8.5.2/workdir/UnoApiHeadersTarget/offapi/normal/com/sun/star/ucb/DuplicateProviderException.hpp <==
#ifndef INCLUDED_COM_SUN_STAR_UCB_DUPLICATEPROVIDEREXCEPTION_HPP
#define INCLUDED_COM_SUN_STAR_UCB_DUPLICATEPROVIDEREXCEPTION_HPP

#include "sal/config.h"

#include "com/sun/star/ucb/DuplicateProviderException.hdl"

#include "com/sun/star/uno/Exception.hpp"
#include "com/sun/star/uno/Type.hxx"
#include "cppu/unotype.hxx"

namespace com { namespace sun { namespace star { namespace ucb {

inline DuplicateProviderException::DuplicateProviderException(
#if defined LIBO_USE_SOURCE_LOCATION
    o3tl::source_location location
#endif
)
    : ::css::uno::Exception(
#if defined LIBO_USE_SOURCE_LOCATION
    location
#endif
)
{ }

inline DuplicateProviderException::DuplicateProviderException(const ::rtl::OUString& Message_, const ::css::uno::Reference< ::css::uno::XInterface >& Context_
#if defined LIBO_USE_SOURCE_LOCATION
    , o3tl::source_location location
#endif
)
    : ::css::uno::Exception(Message_, Context_
#if defined LIBO_USE_SOURCE_LOCATION
    , location
#endif
)
{ }

#if !defined LIBO_INTERNAL_ONLY
DuplicateProviderException::DuplicateProviderException(DuplicateProviderException const & the_other): ::css::uno::Exception(the_other) {}

DuplicateProviderException::~DuplicateProviderException() {}

DuplicateProviderException & DuplicateProviderException::operator =(DuplicateProviderException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::css::uno::Exception::operator =(the_other);
    return *this;
}
#endif

} } } }

namespace com { namespace sun { namespace star { namespace ucb {

inline ::css::uno::Type const & cppu_detail_getUnoType(SAL_UNUSED_PARAMETER ::css::ucb::DuplicateProviderException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.ucb.DuplicateProviderException" );
    }
    return * reinterpret_cast< ::css::uno::Type * >( &the_type );
}

} } } }

SAL_DEPRECATED("use cppu::UnoType") inline ::css::uno::Type const & SAL_CALL getCppuType(SAL_UNUSED_PARAMETER ::css::ucb::DuplicateProviderException const *) {
    return ::cppu::UnoType< ::css::ucb::DuplicateProviderException >::get();
}

#endif // INCLUDED_COM_SUN_STAR_UCB_DUPLICATEPROVIDEREXCEPTION_HPP
